/*
 * WolfDAC control code
 * 15/05/12 v0.1
 *
 * Jobs are:
 *  1. Setup slave defaults
 *  2. Handle incoming IR bitstreams
 *  3. process IR bitsteams and update slave configs
 *
 */

/*
 * ======== Grace related includes ========
 */
#include <ti/mcu/msp430/csl/CSL.h>
/*
 * ======== local includes ========
 */
#include "irdecode.h"
#include "wm8718.h"
#include "wm8804.h"

unsigned char tmp;
//----------------------------------------------------------------------------
int main(int argc, char *argv[])
{
 	//Initialisation
    CSL_init();                     // Activate Grace-generated configuration
    unsigned char savedCmd = 0;

 	//light the lights
	P1OUT |= LED;
	raiseAIFlines();
	//go to sleep until the interval timer fires x10 - gives everything external chance to wake up
	unsigned i;
	for (i=0; i<10; i++)
	_BIS_SR(LPM0_bits + GIE);

	//disable the interval timer from here
	WDTCTL = WDTPW + WDTHOLD;

	//__delay_cycles(65535);
    initDAC();
    initAIF();
    //__delay_cycles(65535);
    volumeDown();

    //global  vars
    tState = eIDLE;
#ifdef TESTDATA
    testDataIndex = 0;
    //errorCount=0;
#endif
    //------END OF INIT---------

    //process loop
    for(;;)
    {
    	_BIS_SR(LPM0_bits + GIE); // go to sleep until next timer interrupt
#ifdef TESTDATA
    	if (testDataIndex == 38)
    		_NOP();
#endif
    	switch (IRStateMachine(LatestPulse)) //new timer interrupt found, process
    	{
    	case eDATACAPTURED:
			//process captured IR data
    		if ((irData[eFIRSTBIT] == IR_BIT1_APPLE) &&
    			(irData[eSECONDBIT] == IR_BIT2_APPLE) &&
    			(irData[eFOURTHBIT] == IR_BIT4_APPLE))
    		{
    			switch (irData[eTHIRDBIT])
    			{
    				case IR_BIT3_VOLUP:
    					volumeUp();
    					break;
    				case IR_BIT3_VOLDN:
    					volumeDown();
    					break;
    				case IR_BIT3_PLAY:
    					mute();
    					break;
    				case IR_BIT3_MENU:
    					richardHawleySetting();
    					break;
    				default:
    					_NOP();
    			}
    			savedCmd = irData[eTHIRDBIT];
    		}
    		else
    		{
    			//although we've got valid data, it wasn't from our designated remote control
    			//we need to wipe out the saved command memory, since that non-valid remote may also issue
    			//repeat commands which aren't checked
    			savedCmd = 0;
    		}
    		break;
    	case eDATAREPEAT:

    		//only allow repeat commands for volume

    		switch (savedCmd)
			{
				case IR_BIT3_VOLUP:
					volumeUp();
					break;
				case IR_BIT3_VOLDN:
					volumeDown();
					break;
			}

    		break;
    	case eERROR:
    		savedCmd = 0; //wipe out repeat command upon error
    	}
    	LatestPulse = ePulseERROR; //reset global, just in case

    	//Check audio input status
    	//tmp = readStatus();


    }
}

//----------------------------------------------------------------------------
//the interval timer fires off each second. Although the ISR isn't used for anything,
// the shear firing of the interrupt pulls the processor out of low power mode, enabling
// the main for loop to execute
void Interval_ISR(void)
{
	_NOP();
} //do nothing
