/*
 *  ======== CSL_init.c ========
 *  DO NOT MODIFY THIS FILE - CHANGES WILL BE OVERWRITTEN
 */
 
/* external peripheral initialization functions */
extern void GPIO_init(void);
extern void BCSplus_init(void);
extern void USI_init(void);
extern void Timer_A2_init(void);
extern void System_init(void);
extern void WDTplus_init(void);

#include <msp430.h>

/*
 *  ======== CSL_init =========
 *  Initialize all configured CSL peripherals
 */
void CSL_init(void)
{
    /* Stop watchdog timer from timing out during initial start-up. */
    WDTCTL = WDTPW + WDTHOLD;

    /* initialize Config for the MSP430 GPIO */
    GPIO_init();

    /* initialize Config for the MSP430 2xx family clock systems (BCS) */
    BCSplus_init();

    /* initialize Config for the MSP430 USI */
    USI_init();

    /* initialize Config for the MSP430 A2 Timer */
    Timer_A2_init();

    /* initialize Config for the MSP430 System Registers */
    System_init();

    /* initialize Config for the MSP430 WDT+ */
    WDTplus_init();

}

/*
 *  ======== Interrupt Function Definitions ========
 */
/* --COPYRIGHT--,EPL
 *  Copyright (c) 2010 Texas Instruments and others.
 *  All rights reserved. This program and the accompanying materials
 *  are made available under the terms of the Eclipse Public License v1.0
 *  which accompanies this distribution, and is available at
 *  http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Contributors:
 *      Texas Instruments - initial implementation
 * 
 * --/COPYRIGHT--*/

/* Interrupt Function Prototypes */
extern void TimerA2_ISR(void);
extern void TimerOverflow_ISR(void);
extern void Interval_ISR(void);





/*
 *  ======== Timer_A2 Interrupt Service Routine ======== 
 */
#pragma vector=TIMERA0_VECTOR
__interrupt void TIMERA0_ISR_HOOK(void)
{

	/* Capture Compare Register 0 ISR Hook Function Name */
	TimerA2_ISR();

	/* Enter active mode on exit */
	__bic_SR_register_on_exit(LPM4_bits);
}

/*
 *  ======== Timer_A2 Interrupt Service Routine ======== 
 */
#pragma vector=TIMERA1_VECTOR
__interrupt void TIMERA1_ISR_HOOK(void)
{

    switch (__even_in_range(TAIV, TAIV_TAIFG))    // Efficient switch-implementation
    {
        case TAIV_TACCR1:
            break;
        case TAIV_TAIFG:
            /* Counter Overflow ISR Hook Function Name */
            TimerOverflow_ISR();

            /* No change in operating mode on exit */
            break;
    }
}


/*
 *  ======== Watchdog Timer Interval Interrupt Handler Generation ========
 */
#pragma vector=WDT_VECTOR
__interrupt void WDT_ISR_HOOK(void)
{


	/* Watchdog Timer Interrupt Handler */
	Interval_ISR();

	/* Enter active mode on exit */
	__bic_SR_register_on_exit(LPM4_bits);
}
