/*
 * wm8804.h
 *
 *  Created on: 5 Jul 2012
 *      Author: mmaher
 *
 *  WM8804 spdif audio interface
 *
 *  lots and lots of registers, won't cover them all here, just the basics
 *
 *  PLL:
 *
 *  default setup for the K/N pll values is based on 12mhz clock inputting 32-96khz inputs (standard)
 *
 */

#ifndef WM8804_H_
#define WM8804_H_
#define AIF_REG_RESET   0x00


#define AIF_REG_DEVIDL  0x00  //read only
#define AIF_REG_DEVIDH  0x01  //read only
#define AIF_REG_DEVREV  0x02  //read only
#define AIF_REG_INTSTAT 0x0B  //read only
#define AIF_REG_SPDSTAT 0x0C  //read only

#define AIF_REG_PLL1    0x03
#define AIF_REG_PLL2    0x04
#define AIF_REG_PLL3    0x05  //use default pll setup
#define AIF_REG_PLL4    0x06
#define AIF_REG_PLL5    0x07
#define AIF_REG_PLL6    0x08
#define AIF_REG_SPDMODE 0x09  //use default
#define AIF_REG_INTMASK 0x0A  //use default

#define AIF_REG_RXCHAN1 0x0D  //read only
#define AIF_REG_RXCHAN2 0x0E  //read only
#define AIF_REG_RXCHAN3 0x0F  //read only
#define AIF_REG_RXCHAN4 0x10  //read only
#define AIF_REG_RXCHAN5 0x11  //read only
#define AIF_REG_SPDTX1  0x12  //ignore, not in use
#define AIF_REG_SPDTX2  0x13  //ignore, not in use
#define AIF_REG_SPDTX3  0x14  //ignore, not in use
#define AIF_REG_SPDTX4  0x15  //ignore, not in use
#define AIF_REG_SPDTX5  0x16  //ignore, not in use
#define AIF_REG_GPIO0   0x17  //ignore, not in use
#define AIF_REG_GPIO1   0x18  //ignore, not in use
#define AIF_REG_GPIO2   0x1A  //ignore, not in use
#define AIF_REG_AIFTX   0x1B //   00000110

#define AIF_REG_AIFRX   0x1C //01000000 - master i2s, 16bit , i2s mode, nothing inverted
#define AIF_REG_SPDRX1  0x1D //use default - 10000000 - no flags, 192khz support
#define AIF_REG_PWRDN   0x1E //00000100 - everthing up except spdif transmitter

#define SPI_WRITE 0x00 //msb is the read/write bit
#define SPI_READ  0x80
#define SPI_DUMMY 0x00

#include "globals.h"

unsigned char readDevID();
unsigned char readStatus();
unsigned char AIFid;

unsigned char SPIaction(unsigned char RWflag, unsigned char reg, unsigned char data)
{
	//load high byte & low byte (spi is in 16bit operation)
	USISRL = data;
	USISRH = (RWflag | reg);

	//USISR = ((RWflag | reg) << 8) | data;

	//drop CS for device
	P1OUT &= ~AIF;

	//increment count to start TX
	USICNT |= 16;

	//unsigned i;
	//for (i = 0xFFFF; i > 0; i--);           // Delay until tx'd
	while (!(USIIFG & USICTL1));            // Counter clear?

	//raise CS for device
	P1OUT |= AIF;

	return USISRL;
}
void raiseAIFlines()
{
    //raise SPI CS line
    P1OUT |= AIF;
    //raise gpio (aif reset)
    P1OUT |= AIF_RESET;
}
void initAIF()
{
    AIFid = readDevID();

    SPIaction(SPI_WRITE, AIF_REG_AIFTX, 0x06); //06 - 20bit i2s
	SPIaction(SPI_WRITE, AIF_REG_AIFRX, 0x46); //46 - master mode, 20bit i2s
	SPIaction(SPI_WRITE, AIF_REG_PWRDN, 0x04);
}

unsigned char readDevID()
{
	return SPIaction(SPI_READ, AIF_REG_DEVIDH, SPI_DUMMY);
}

unsigned char readStatus()
{
	return SPIaction(SPI_READ, AIF_REG_SPDSTAT, SPI_DUMMY);
}

#endif /* WM8804_H_ */
